# banana-cli (WORK IN PROGRESS)

The Banana CLI helps you build Potassium apps

To download the CLI

```bash
pip3 install -u banana-cli
```

To initialize a Potassium backend project

```bash
mkdir my-project
cd my-project
banana init
```

To download dependencies

```bash
virtualenv venv
. ./venv/bin/activate
pip3 install -r requirements.txt
```

To run the server directly

```bash
python3 app.py
```
